==> estateplat-common-1.2.4-20201106.071614-492-sources.jar: cn/gtmap/estateplat/model/exchange/unidofrmity/QlfQlYgdjBdc.java <==
package cn.gtmap.estateplat.model.exchange.unidofrmity;

import cn.gtmap.estateplat.model.exchange.national.QlfQlYgdj;
import cn.gtmap.estateplat.utils.JaxbStringAdapter;

import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlTransient;
import javax.xml.bind.annotation.adapters.XmlJavaTypeAdapter;

public class QlfQlYgdjBdc extends QlfQlYgdj {
    private String dfywrzjzldm;
    private String dfywrzjzlmc;
    private String dfygdjzldm;
    private String dfygdjzlmc;
    private String dfdjlxdm;
    private String dfdjlxmc;
    private String dfghytdm;
    private String dfghytmc;
    private String dffwxzdm;
    private String dffwxzmc;
    private String dffwjgdm;
    private String dffwjgmc;
    private String dfqsztdm;
    private String dfqsztmc;
    @XmlAttribute(
            name = "DFYWRZJZLDM"
    )
    public String getDfywrzjzldm() {
        return dfywrzjzldm;
    }

    public void setDfywrzjzldm(String dfywrzjzldm) {
        this.dfywrzjzldm = dfywrzjzldm;
    }
    @XmlTransient
    public String getDfywrzjzlmc() {
        return dfywrzjzlmc;
    }

    public void setDfywrzjzlmc(String dfywrzjzlmc) {
        this.dfywrzjzlmc = dfywrzjzlmc;
    }
    @XmlAttribute(
            name = "DFYGDJZLDM"
    )
    @XmlJavaTypeAdapter(JaxbStringAdapter.class)
    public String getDfygdjzldm() {
        return dfygdjzldm;
    }

    public void setDfygdjzldm(String dfygdjzldm) {
        this.dfygdjzldm = dfygdjzldm;
    }
    @XmlTransient
    public String getDfygdjzlmc() {
        return dfygdjzlmc;
    }

    public void setDfygdjzlmc(String dfygdjzlmc) {
        this.dfygdjzlmc = dfygdjzlmc;
    }
    @XmlAttribute(
            name = "DFDJLXDM"
    )
    @XmlJavaTypeAdapter(JaxbStringAdapter.class)
    public String getDfdjlxdm() {
        return dfdjlxdm;
    }

    public void setDfdjlxdm(String dfdjlxdm) {
        this.dfdjlxdm = dfdjlxdm;
    }
    @XmlTransient
    public String getDfdjlxmc() {
        return dfdjlxmc;
    }

    public void setDfdjlxmc(String dfdjlxmc) {
        this.dfdjlxmc = dfdjlxmc;
    }
    @XmlAttribute(
            name = "DFGHYTDM"
    )
    public String getDfghytdm() {
        return dfghytdm;
    }

    public void setDfghytdm(String dfghytdm) {
        this.dfghytdm = dfghytdm;
    }

    @XmlTransient
    public String getDfghytmc() {
        return dfghytmc;
    }

    public void setDfghytmc(String dfghytmc) {
        this.dfghytmc = dfghytmc;
    }
    @XmlAttribute(
            name = "DFFWXZDM"
    )
    public String getDffwxzdm() {
        return dffwxzdm;
    }

    public void setDffwxzdm(String dffwxzdm) {
        this.dffwxzdm = dffwxzdm;
    }
    @XmlTransient
    public String getDffwxzmc() {
        return dffwxzmc;
    }

    public void setDffwxzmc(String dffwxzmc) {
        this.dffwxzmc = dffwxzmc;
    }
    @XmlAttribute(
            name = "DFFWJGDM"
    )
    public String getDffwjgdm() {
        return dffwjgdm;
    }

    public void setDffwjgdm(String dffwjgdm) {
        this.dffwjgdm = dffwjgdm;
    }
    @XmlTransient
    public String getDffwjgmc() {
        return dffwjgmc;
    }

    public void setDffwjgmc(String dffwjgmc) {
        this.dffwjgmc = dffwjgmc;
    }
    @XmlAttribute(
            name = "DFQSZTDM"
    )
    @XmlJavaTypeAdapter(JaxbStringAdapter.class)
    public String getDfqsztdm() {
        return dfqsztdm;
    }

    public void setDfqsztdm(String dfqsztdm) {
        this.dfqsztdm = dfqsztdm;
    }
    @XmlAttribute(
            name = "DFQSZTMC"
    )
    @XmlJavaTypeAdapter(JaxbStringAdapter.class)
    public String getDfqsztmc() {
        return dfqsztmc;
    }

    public void setDfqsztmc(String dfqsztmc) {
        this.dfqsztmc = dfqsztmc;
    }
}

==> estateplat-common-1.2.4-20201112.062002-497-sources.jar: cn/gtmap/estateplat/model/exchange/unidofrmity/QlfQlYgdjBdc.java <==
package cn.gtmap.estateplat.model.exchange.unidofrmity;

import cn.gtmap.estateplat.model.exchange.national.QlfQlYgdj;
import cn.gtmap.estateplat.utils.JaxbStringAdapter;

import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlTransient;
import javax.xml.bind.annotation.adapters.XmlJavaTypeAdapter;

public class QlfQlYgdjBdc extends QlfQlYgdj {
    private String dfywrzjzldm;
    private String dfywrzjzlmc;
    private String dfygdjzldm;
    private String dfygdjzlmc;
    private String dfdjlxdm;
    private String dfdjlxmc;
    private String dfghytdm;
    private String dfghytmc;
    private String dffwxzdm;
    private String dffwxzmc;
    private String dffwjgdm;
    private String dffwjgmc;
    private String dfqsztdm;
    private String dfqsztmc;
    @XmlAttribute(
            name = "DFYWRZJZLDM"
    )
    @XmlJavaTypeAdapter(JaxbStringAdapter.class)
    public String getDfywrzjzldm() {
        return dfywrzjzldm;
    }

    public void setDfywrzjzldm(String dfywrzjzldm) {
        this.dfywrzjzldm = dfywrzjzldm;
    }
    @XmlAttribute(
            name = "DFYWRZJZLMC"
    )
    @XmlJavaTypeAdapter(JaxbStringAdapter.class)
    public String getDfywrzjzlmc() {
        return dfywrzjzlmc;
    }

    public void setDfywrzjzlmc(String dfywrzjzlmc) {
        this.dfywrzjzlmc = dfywrzjzlmc;
    }
    @XmlAttribute(
            name = "DFYGDJZLDM"
    )
    @XmlJavaTypeAdapter(JaxbStringAdapter.class)
    public String getDfygdjzldm() {
        return dfygdjzldm;
    }

    public void setDfygdjzldm(String dfygdjzldm) {
        this.dfygdjzldm = dfygdjzldm;
    }
    @XmlAttribute(
            name = "DFYGDJZLMC"
    )
    @XmlJavaTypeAdapter(JaxbStringAdapter.class)
    public String getDfygdjzlmc() {
        return dfygdjzlmc;
    }

    public void setDfygdjzlmc(String dfygdjzlmc) {
        this.dfygdjzlmc = dfygdjzlmc;
    }
    @XmlAttribute(
            name = "DFDJLXDM"
    )
    @XmlJavaTypeAdapter(JaxbStringAdapter.class)
    public String getDfdjlxdm() {
        return dfdjlxdm;
    }

    public void setDfdjlxdm(String dfdjlxdm) {
        this.dfdjlxdm = dfdjlxdm;
    }
    @XmlAttribute(
            name = "DFDJLXMC"
    )
    @XmlJavaTypeAdapter(JaxbStringAdapter.class)
    public String getDfdjlxmc() {
        return dfdjlxmc;
    }

    public void setDfdjlxmc(String dfdjlxmc) {
        this.dfdjlxmc = dfdjlxmc;
    }
    @XmlAttribute(
            name = "DFGHYTDM"
    )
    @XmlJavaTypeAdapter(JaxbStringAdapter.class)
    public String getDfghytdm() {
        return dfghytdm;
    }

    public void setDfghytdm(String dfghytdm) {
        this.dfghytdm = dfghytdm;
    }

    @XmlAttribute(
            name = "DFGHYTMC"
    )
    @XmlJavaTypeAdapter(JaxbStringAdapter.class)
    public String getDfghytmc() {
        return dfghytmc;
    }

    public void setDfghytmc(String dfghytmc) {
        this.dfghytmc = dfghytmc;
    }
    @XmlAttribute(
            name = "DFFWXZDM"
    )
    @XmlJavaTypeAdapter(JaxbStringAdapter.class)
    public String getDffwxzdm() {
        return dffwxzdm;
    }

    public void setDffwxzdm(String dffwxzdm) {
        this.dffwxzdm = dffwxzdm;
    }
    @XmlAttribute(
            name = "DFFWXZMC"
    )
    @XmlJavaTypeAdapter(JaxbStringAdapter.class)
    public String getDffwxzmc() {
        return dffwxzmc;
    }

    public void setDffwxzmc(String dffwxzmc) {
        this.dffwxzmc = dffwxzmc;
    }
    @XmlAttribute(
            name = "DFFWJGDM"
    )
    @XmlJavaTypeAdapter(JaxbStringAdapter.class)
    public String getDffwjgdm() {
        return dffwjgdm;
    }

    public void setDffwjgdm(String dffwjgdm) {
        this.dffwjgdm = dffwjgdm;
    }
    @XmlAttribute(
            name = "DFFWJGMC"
    )
    @XmlJavaTypeAdapter(JaxbStringAdapter.class)
    public String getDffwjgmc() {
        return dffwjgmc;
    }

    public void setDffwjgmc(String dffwjgmc) {
        this.dffwjgmc = dffwjgmc;
    }
    @XmlAttribute(
            name = "DFQSZTDM"
    )
    @XmlJavaTypeAdapter(JaxbStringAdapter.class)
    public String getDfqsztdm() {
        return dfqsztdm;
    }

    public void setDfqsztdm(String dfqsztdm) {
        this.dfqsztdm = dfqsztdm;
    }
    @XmlAttribute(
            name = "DFQSZTMC"
    )
    @XmlJavaTypeAdapter(JaxbStringAdapter.class)
    public String getDfqsztmc() {
        return dfqsztmc;
    }

    public void setDfqsztmc(String dfqsztmc) {
        this.dfqsztmc = dfqsztmc;
    }
}
